summaryrefslogtreecommitdiff
path: root/Source/Dafny/Compiler.cs
diff options
context:
space:
mode:
authorGravatar Rustan Leino <leino@microsoft.com>2012-10-22 02:18:51 -0700
committerGravatar Rustan Leino <leino@microsoft.com>2012-10-22 02:18:51 -0700
commit2541e9de002267359897bf967755172fcc726512 (patch)
tree43fcf2056a460973bb4619e2ac1d060343bd28bc /Source/Dafny/Compiler.cs
parentaba7928452a9043ab1cc6f4fd2e0dda4e2273508 (diff)
renamed "abstract module" to "module facade"
renamed "ghost module" to "abstract module", adding a keyword "abstract"
Diffstat (limited to 'Source/Dafny/Compiler.cs')
-rw-r--r--Source/Dafny/Compiler.cs4
1 files changed, 2 insertions, 2 deletions
diff --git a/Source/Dafny/Compiler.cs b/Source/Dafny/Compiler.cs
index dd50c4eb..4b59682f 100644
--- a/Source/Dafny/Compiler.cs
+++ b/Source/Dafny/Compiler.cs
@@ -68,8 +68,8 @@ namespace Microsoft.Dafny {
CompileBuiltIns(program.BuiltIns);
foreach (ModuleDefinition m in program.CompileModules) {
- if (m.IsGhost) {
- // the purpose of a ghost module is to skip compilation
+ if (m.IsAbstract) {
+ // the purpose of an abstract module is to skip compilation
continue;
}
int indent = 0;